Enum amazon_sp_product_fees::models::optional_fulfillment_program::OptionalFulfillmentProgram
source · [−]pub enum OptionalFulfillmentProgram {
CORE,
SNL,
EFN,
}Expand description
OptionalFulfillmentProgram : An optional enrollment program to return the estimated fees when the offer is fulfilled by Amazon (IsAmazonFulfilled is set to true). An optional enrollment program to return the estimated fees when the offer is fulfilled by Amazon (IsAmazonFulfilled is set to true).
Variants
CORE
SNL
EFN